@@ -41,6 +41,19 @@ on_album_title_focus_out_event         (GtkWidget       *widget,
                                         GdkEventFocus   *event,
                                         gpointer         user_data);
 
+// lnr
+gboolean
+on_album_genre_focus_out_event         (GtkWidget       *widget,
+                                        GdkEventFocus   *event,
+                                        gpointer         user_data);
+
+// lnr
+void
+on_genre_edited                    (GtkCellRendererText *cell,
+                                     gchar               *path_string,
+                                     gchar               *new_text,
+                                     gpointer             user_data);
+
 void
 on_artist_edited                    (GtkCellRendererText *cell,
                                      gchar               *path_string,
@@ -127,6 +140,11 @@ void
 on_single_artist_toggled               (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
+// lnr
+void
+on_single_genre_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
 void
 on_rip_ogg_toggled                     (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
