@@ -29,64 +29,55 @@ Foundation; version 2 of the licence.
 
 void debugLog(const char* format, ...)
 {
+    if(!global_prefs->do_log)
+        return;
+    
     va_list ap;
     const char* p = format;
     
     FILE* logFile = NULL;
     
-    if(global_prefs->do_log)
-    {
-        logFile = fopen(LOG_FILE, "a");
-        if(logFile == NULL)
-            return;
-    }
+    logFile = fopen(LOG_FILE, "a");
+    if(logFile == NULL)
+        return;
     
     va_start(ap, format);
     
-    time_t currentTime = time(NULL);
-    char* currentTimeStr = ctime(&currentTime);
-    currentTimeStr[strlen(currentTimeStr) - 1] = '\0';
-    
     while (*p && *(p + 1))
     {
         if (*p == '%')
         {
             if (*(p + 1) == 'd')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%d", va_arg(ap, int));
+                fprintf(logFile, "%d", va_arg(ap, int));
 #ifdef DEBUG
                 printf("%d", va_arg(ap, int));
 #endif
             }
             else if (*(p + 1) == 'x')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%x", va_arg(ap, unsigned int));
+                fprintf(logFile, "%x", va_arg(ap, unsigned int));
 #ifdef DEBUG
                 printf("%x", va_arg(ap, unsigned int));
 #endif
             }
             else if (*(p + 1) == 'X')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%X", va_arg(ap, unsigned int));
+                fprintf(logFile, "%X", va_arg(ap, unsigned int));
 #ifdef DEBUG
                 printf("%X", va_arg(ap, unsigned int));
 #endif
             }
             else if (*(p + 1) == 'o')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%o", va_arg(ap, unsigned int));
+                fprintf(logFile, "%o", va_arg(ap, unsigned int));
 #ifdef DEBUG
                 printf("%o", va_arg(ap, unsigned int));
 #endif
             }
             else if (*(p + 1) == 'u')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%u", va_arg(ap, unsigned int));
+                fprintf(logFile, "%u", va_arg(ap, unsigned int));
 #ifdef DEBUG
                 printf("%u", va_arg(ap, unsigned int));
 #endif
@@ -94,8 +85,7 @@ void debugLog(const char* format, ...)
             else if (*(p + 1) == '.' && *(p + 2) && *(p + 2) >= '0' && *(p + 2) <= '9' && 
                      *(p + 3) && *(p + 3) == 'f')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+                fprintf(logFile, "%.2lf", va_arg(ap, double));
 #ifdef DEBUG
                 printf("%.2lf", va_arg(ap, double));
 #endif
@@ -103,8 +93,7 @@ void debugLog(const char* format, ...)
             }
             else if(*(p + 1) == 'f')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+                fprintf(logFile, "%.2lf", va_arg(ap, double));
 #ifdef DEBUG
                 printf("%.2lf", va_arg(ap, double));
 #endif
@@ -112,8 +101,7 @@ void debugLog(const char* format, ...)
             else if (*(p + 1) == '.' && *(p + 2) && *(p + 2) >= '0' && *(p + 2) <= '9' && 
                      *(p + 3) && *(p + 3) == 'l' && *(p + 4) && *(p + 4) == 'f')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+                fprintf(logFile, "%.2lf", va_arg(ap, double));
 #ifdef DEBUG
                 printf("%.2lf", va_arg(ap, double));
 #endif
@@ -121,16 +109,14 @@ void debugLog(const char* format, ...)
             }
             else if(*(p + 1) == 'l' && *(p + 2) && *(p + 2) == 'f')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%.2lf", va_arg(ap, double));
+                fprintf(logFile, "%.2lf", va_arg(ap, double));
 #ifdef DEBUG
                 printf("%.2lf", va_arg(ap, double));
 #endif
             }
             else if (*(p + 1) == 'c')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%c", (char)va_arg(ap, int));
+                fprintf(logFile, "%c", (char)va_arg(ap, int));
 #ifdef DEBUG
                 printf("%c", (char)va_arg(ap, int));
 #endif
@@ -140,16 +126,14 @@ void debugLog(const char* format, ...)
                 char* str = va_arg(ap, char*);
                 if (str == NULL)
                 {
-                    if(global_prefs->do_log)
-                        fprintf(logFile, "NULL");
+                    fprintf(logFile, "NULL");
 #ifdef DEBUG
                     printf("NULL");
 #endif
                 }
                 else
                 {
-                    if(global_prefs->do_log)
-                        fprintf(logFile, "%s", str);
+                    fprintf(logFile, "%s", str);
 #ifdef DEBUG
                     printf("%s", str);
 #endif
@@ -157,8 +141,7 @@ void debugLog(const char* format, ...)
             }
             else if (*(p + 1) == '%')
             {
-                if(global_prefs->do_log)
-                    fprintf(logFile, "%%");
+                fprintf(logFile, "%%");
 #ifdef DEBUG
                 printf("%%");
 #endif
@@ -168,8 +151,7 @@ void debugLog(const char* format, ...)
                 //~ fprintf(logFile, "<<%d %d %d %d %d %d %d %d>>\n",
                 //~ *(p + 1) == '.', *(p + 2), *(p + 2) >= 0, *(p + 2) <= 9, 
                       //~ *(p + 3), *(p + 3) == 'l', *(p + 4), *(p + 4) == 'f');
-                if(global_prefs->do_log)
-                    fprintf(logFile, "unsupported format flag '%c'", *(p + 1));
+                fprintf(logFile, "unsupported format flag '%c'", *(p + 1));
 #ifdef DEBUG
                 printf("unsupported format flag '%c'", *(p + 1));
 #endif
@@ -179,8 +161,7 @@ void debugLog(const char* format, ...)
         }
         else /* last character on the line */
         {
-            if(global_prefs->do_log)
-                fprintf(logFile, "%c", *p);
+            fprintf(logFile, "%c", *p);
 #ifdef DEBUG
             printf("%c", *p);
 #endif
@@ -190,15 +171,13 @@ void debugLog(const char* format, ...)
     }
     if (*p)
     {
-        if(global_prefs->do_log)
-            fprintf(logFile, "%c", *p);
+        fprintf(logFile, "%c", *p);
 #ifdef DEBUG
         printf("%c", *p);
 #endif
     }
     
-    if(global_prefs->do_log)
-        fclose(logFile);
+    fclose(logFile);
 }
 
 void fatalError(const char* message)
@@ -522,12 +501,13 @@ void make_playlist(const char* filename, FILE** file)
 //
 // format - the format of the filename
 // tracknum - gets substituted for %N in format
+// year - gets substituted for %Y in format
 // artist - gets substituted for %A in format
 // album - gets substituted for %L in format
 // title - gets substituted for %T in format
 //
 // NOTE: caller must free the returned string!
-char * parse_format(const char * format, int tracknum, const char * artist, const char * album, const char * title)
+char * parse_format(const char * format, int tracknum, int year, const char * artist, const char * album, const char * title)
 {
     unsigned i = 0;
     int len = 0;
@@ -549,6 +529,12 @@ char * parse_format(const char * format, int tracknum, const char * artist, cons
                 case 'N':
                     if ((tracknum > 0) && (tracknum < 100)) len += 2;
                     break;
+                case 'Y':
+                    if ((year > 0) && (year < 10000))
+                        len += 4;
+                    else
+                        len += 1;
+                    break;
                 case 'T':
                     if (title) len += strlen(title);
                     break;
@@ -595,6 +581,21 @@ char * parse_format(const char * format, int tracknum, const char * artist, cons
                         pos += 2;
                     }
                     break;
+                case 'Y':
+                    if ((year > 0) && (year < 10000))
+                    {
+                        ret[pos] = '0'+(year/1000);
+                        ret[pos+1] = '0'+((year/100)%10);
+                        ret[pos+2] = '0'+((year/10)%10);
+                        ret[pos+3] = '0'+(year%10);
+                        pos += 4;
+                    }
+                    else
+                    {
+                        ret[pos] = '0';
+                        pos += 1;
+                    }
+                    break;
                 case 'T':
                     if (title)
                     {
@@ -801,7 +802,7 @@ void trim_chars(char * str, const char * bad)
     int pos;
     int len = strlen(str);
     unsigned b;
-    
+
     for (b=0; b<strlen(bad); b++)
     {
         pos = 0;
