@@ -396,6 +396,8 @@ void lame(int tracknum,
     char bitrate_text[4];
     const char * args[18];
 
+//    fprintf( stderr, " lame()   Genre: %s Artist: %s Title: %s\n", genre, artist, title );	// lnr
+
     snprintf(tracknum_text, 3, "%d", tracknum);
     
     pos = 0;
@@ -429,12 +431,18 @@ void lame(int tracknum,
         args[pos++] = "--tt";
         args[pos++] = title;
     }
-    // lame refuses to accept somegenres that come from cddb, and users get upset
-    if (false && (genre != NULL) && (strlen(genre) > 0))
+
+    // lame refuses to accept some genres that come from cddb, and users get upset
+    // No longer an issue - users can now edit the genre field -lnr 
+
+    // if (false && (genre != NULL) && (strlen(genre) > 0))
+    if (( genre != NULL )								// lnr
+    &&  ( strlen( genre )))
     {
         args[pos++] = "--tg";
         args[pos++] = genre;
     }
+
     if ((year != NULL) && (strlen(year) > 0))
     {
         args[pos++] = "--ty";
@@ -494,6 +502,7 @@ void oggenc(int tracknum,
             char * artist,
             char * album,
             char * title,
+            char * year,
             char * genre,
             char * wavfilename,
             char * oggfilename,
@@ -511,7 +520,7 @@ void oggenc(int tracknum,
 
     char tracknum_text[3];
     char quality_level_text[3];
-    const char * args[17];
+    const char * args[19];
 
     snprintf(tracknum_text, 3, "%d", tracknum);
     snprintf(quality_level_text, 3, "%d", quality_level);
@@ -540,6 +549,11 @@ void oggenc(int tracknum,
     {
         args[pos++] = "-t";
         args[pos++] = title;
+    } 
+    if ((year != NULL) && (strlen(year) > 0))
+    {
+        args[pos++] = "-d";
+        args[pos++] = year;
     }
     if ((genre != NULL) && (strlen(genre) > 0))
     {
